var plplotc_8py =
[
    [ "_object", "classplplotc_1_1__object.html", null ],
    [ "PLGraphicsIn", "classplplotc_1_1PLGraphicsIn.html", "classplplotc_1_1PLGraphicsIn" ],
    [ "_swig_getattr", "plplotc_8py.html#a042b92b45149d894e6b7beb95945af8f", null ],
    [ "_swig_repr", "plplotc_8py.html#ad2998dd0f98e563a7a1d5121e1c5e755", null ],
    [ "_swig_setattr", "plplotc_8py.html#a6049fc77c872d6500b973ea6e4ae0e88", null ],
    [ "_swig_setattr_nondynamic", "plplotc_8py.html#aa975bfbfbe29d7f2a77c97aa93ceb35c", null ],
    [ "pl_setcontlabelformat", "plplotc_8py.html#a8ab8a73f442661a1a7dcd442e4344abd", null ],
    [ "pl_setcontlabelparam", "plplotc_8py.html#a33d95ff04a0f918ed66ba62b3debcb2f", null ],
    [ "pladv", "plplotc_8py.html#af583a68f2c57ad3a10afa84d4c9c9c2d", null ],
    [ "plarc", "plplotc_8py.html#a9be18d453d704695751bd8f987a09a11", null ],
    [ "plaxes", "plplotc_8py.html#a479636ed3ea5b202abcf3986a9bd054e", null ],
    [ "plbin", "plplotc_8py.html#abd2d7e89b3b2eee76b8ee6e7ca638cd1", null ],
    [ "plbop", "plplotc_8py.html#aa4f7ed53189b8d8fbcfee3c5fc08531b", null ],
    [ "plbox", "plplotc_8py.html#a34684f1a5ffc6442b6d6e10a8fdd697a", null ],
    [ "plbox3", "plplotc_8py.html#aba139dfc60561e0831dc087fcb97c68f", null ],
    [ "plbtime", "plplotc_8py.html#a3cd342202ca88e935bf6fe48090500b9", null ],
    [ "plcalc_world", "plplotc_8py.html#ad57ebe151da0a0e367fd87f51d241418", null ],
    [ "plclear", "plplotc_8py.html#ae1067eddb4f4cac6b18b2bf2da4ecef6", null ],
    [ "plClearOpts", "plplotc_8py.html#a1a1d15575d91a6607499e490d82d04cd", null ],
    [ "plcol0", "plplotc_8py.html#afa58970bd99c3b9e035d8a40babb132f", null ],
    [ "plcol1", "plplotc_8py.html#ad8da6be9dd72c40a28345fd2279f8bb3", null ],
    [ "plcolorbar", "plplotc_8py.html#afac4df8536d3c9aeeb471fecda09e944", null ],
    [ "plconfigtime", "plplotc_8py.html#a8336cb69d54ae22323d6f299d1b4da6e", null ],
    [ "plcont", "plplotc_8py.html#a21ae998afe53ca0a233d068bd2f4670e", null ],
    [ "plcpstrm", "plplotc_8py.html#a14a78ccdefb0fc211398d46e99d0c13e", null ],
    [ "plctime", "plplotc_8py.html#a216f97bf2af523532a1c1265939ad923", null ],
    [ "plend", "plplotc_8py.html#a50544f152cab71eea24e2f408985d2f7", null ],
    [ "plend1", "plplotc_8py.html#a542f2484c3680fbc29952b83ba4726f3", null ],
    [ "plenv", "plplotc_8py.html#aafa732938310a69d4cf8f8f3a431eb01", null ],
    [ "plenv0", "plplotc_8py.html#a0277fab4399d9fd6f0fe282e0a590673", null ],
    [ "pleop", "plplotc_8py.html#aa2ecc6e265412694d9207249f18d27d7", null ],
    [ "plerrx", "plplotc_8py.html#a8da5d144b84d9309a57db78430ebde4d", null ],
    [ "plerry", "plplotc_8py.html#aa486aaf90919dbb3dd0b2f492853064a", null ],
    [ "plfamadv", "plplotc_8py.html#a284024c01bdf5a786bfbadaac698c534", null ],
    [ "plfill", "plplotc_8py.html#a2ce5fae3b5159cacfe9bdb433dfa9157", null ],
    [ "plfill3", "plplotc_8py.html#afac538dce1ced36403331d0cf5de3c35", null ],
    [ "plflush", "plplotc_8py.html#a6d06d0d904f0903c64f0bf794698b59f", null ],
    [ "plfont", "plplotc_8py.html#a5f0bac8abd3eb935a5753cae2aa34c7e", null ],
    [ "plfontld", "plplotc_8py.html#ac1fd8e6e5ab9260523ddc0a10c5abd62", null ],
    [ "plgchr", "plplotc_8py.html#aa6ab9b2911ef8219b8ccdd415eafbedf", null ],
    [ "plgcmap1_range", "plplotc_8py.html#aa9c55675158385c704c618977ad6816f", null ],
    [ "plgcol0", "plplotc_8py.html#adbf054168968898916e7c72cab868a38", null ],
    [ "plgcol0a", "plplotc_8py.html#a2b8b105d0d4ebca338c839bb94c6a56f", null ],
    [ "plgcolbg", "plplotc_8py.html#a2b466c4c9cd98e823a80d2f644d081ac", null ],
    [ "plgcolbga", "plplotc_8py.html#a3f6a46a85512db3c0bd4bf1fd25f12dd", null ],
    [ "plgcompression", "plplotc_8py.html#a397b56a3c430ad142e60daa9132a9dba", null ],
    [ "plgdev", "plplotc_8py.html#a4710982dcc3f14d216fdd89c747c6aca", null ],
    [ "plgdidev", "plplotc_8py.html#ab92864b00dcb5da030a4eb4ec9b17e69", null ],
    [ "plgdiori", "plplotc_8py.html#a632d97320288890cc187ffd3bfde3047", null ],
    [ "plgdiplt", "plplotc_8py.html#a8c93eada6a8d59c266355b56a4fb90a9", null ],
    [ "plGetCursor", "plplotc_8py.html#ac185de5275d2d3b8fa07da707bb1a840", null ],
    [ "plgfam", "plplotc_8py.html#ab953ce74c86b0a6af046d899b25b4ac0", null ],
    [ "plgfci", "plplotc_8py.html#af246a7e57adb82f9861d51321b7187f1", null ],
    [ "plgfnam", "plplotc_8py.html#a16707c077a8820b4b197a7f0f8978c55", null ],
    [ "plgfont", "plplotc_8py.html#a287b473a4d98f0ede72d0b85496cbfb8", null ],
    [ "plglevel", "plplotc_8py.html#a8be4a61a9f81741527baca2d1aa4f78b", null ],
    [ "plgpage", "plplotc_8py.html#ad3594ab92016d7cfee6bccc5f4cbdfa1", null ],
    [ "plgra", "plplotc_8py.html#a67c6ab4faba0156f73e2fd298c951037", null ],
    [ "plgradient", "plplotc_8py.html#a26c945bc031af1e0feda7ff4d6c31b88", null ],
    [ "plgriddata", "plplotc_8py.html#adc026d73c5ff812949be86ce8be29359", null ],
    [ "plgspa", "plplotc_8py.html#ab711a13f79b57e0fa5c9afb95df0acac", null ],
    [ "plgstrm", "plplotc_8py.html#a4110531d0c4526c76cc91a97f1db285f", null ],
    [ "plgver", "plplotc_8py.html#a0aee5c72c16c438df1490cb8613ba382", null ],
    [ "plgvpd", "plplotc_8py.html#a2c1c38e0759eeb5d5bef5345776b332d", null ],
    [ "plgvpw", "plplotc_8py.html#a40b90611c29632a350ade05b197b5fca", null ],
    [ "plgxax", "plplotc_8py.html#a51c738a1d0efd3a11df0a7af0e13c55c", null ],
    [ "plgyax", "plplotc_8py.html#a9b0559f0137a87bc47ad35e6369bb8ec", null ],
    [ "plgzax", "plplotc_8py.html#adeb8adc94db81faf895f3d3a2890f915", null ],
    [ "plhist", "plplotc_8py.html#a4af1ca6180c5bf934efe37fe37fb6d9c", null ],
    [ "plhlsrgb", "plplotc_8py.html#a6458dd802d485ca34070898d5c3f7dea", null ],
    [ "plimage", "plplotc_8py.html#aecc022c1d886285f30db7fd6ecfaa8e1", null ],
    [ "plimagefr", "plplotc_8py.html#acfd9b3b248294f383730006cb3a52020", null ],
    [ "plinit", "plplotc_8py.html#ab997eb38d86d6aa688aa6e2d5bb7f3f0", null ],
    [ "pljoin", "plplotc_8py.html#ad79121d59f024068ad20202beeebfb2a", null ],
    [ "pllab", "plplotc_8py.html#ae85f3766f7a43c7ed307ac1b74ac5df0", null ],
    [ "pllegend", "plplotc_8py.html#a920b8a0de02ea8c0ca5090df7bcb3db7", null ],
    [ "pllightsource", "plplotc_8py.html#a229873e9ce3283f8fa6365cb87857eab", null ],
    [ "plline", "plplotc_8py.html#a62ee9997fa0ba79fa7f5f8fcc8eef0ea", null ],
    [ "plline3", "plplotc_8py.html#a8fd9d69aa3170208205856d4064ca516", null ],
    [ "pllsty", "plplotc_8py.html#a7e9b987800e5277fbc195b56cd5f3f49", null ],
    [ "plmap", "plplotc_8py.html#a5b6affc993be756b21ece7816c404478", null ],
    [ "plmapfill", "plplotc_8py.html#afcfb870505c6a81be260e877afb10e04", null ],
    [ "plmapline", "plplotc_8py.html#a6ea9579f132977e03636ac5d85abc59a", null ],
    [ "plmapstring", "plplotc_8py.html#aa0521b644a979a1db294bd2be252e94e", null ],
    [ "plmaptex", "plplotc_8py.html#aa34e47b4fecf4a423514588598878816", null ],
    [ "plmeridians", "plplotc_8py.html#a5f2729d44d5402bb9f945420feee2d67", null ],
    [ "plmesh", "plplotc_8py.html#af3e6d0fdad8b6a67427930d147139206", null ],
    [ "plmeshc", "plplotc_8py.html#a0e79d559d9865a74922926294fa6dda5", null ],
    [ "plMinMax2dGrid", "plplotc_8py.html#a332b6c5999492e08435d039e4bbad8a4", null ],
    [ "plmkstrm", "plplotc_8py.html#a1d8319f797e9f53b5afd0a8810ebbeac", null ],
    [ "plmtex", "plplotc_8py.html#acf3381edf3d208671ccb53814514911e", null ],
    [ "plmtex3", "plplotc_8py.html#a1afa7d700b635c95f015fd10d6465c95", null ],
    [ "plOptUsage", "plplotc_8py.html#a27d542ff94d76e42de04ef30585fc50a", null ],
    [ "plot3d", "plplotc_8py.html#a7a9ba3ef7a0bb60b4eac4aa236de4b98", null ],
    [ "plot3dc", "plplotc_8py.html#aac2ea1fff46d74f568482a3640d41f70", null ],
    [ "plot3dcl", "plplotc_8py.html#a6cf04ee7329415499e24afb3cb29a559", null ],
    [ "plparseopts", "plplotc_8py.html#a1242422fc2b29e70bb4030ccd9e28d58", null ],
    [ "plpat", "plplotc_8py.html#a1e36abe9d73c06159da88a5b1b76c6be", null ],
    [ "plpath", "plplotc_8py.html#aeaecfb196d22727fe225e23c860a48e8", null ],
    [ "plpoin", "plplotc_8py.html#a645de43686f78824df2f1d3276fba5eb", null ],
    [ "plpoin3", "plplotc_8py.html#a429f1ad59efea415d265890e15b460ed", null ],
    [ "plpoly3", "plplotc_8py.html#a9a7a636dc75666a558787d16530bca78", null ],
    [ "plprec", "plplotc_8py.html#a7329327c51c3bfd4ced36b56b131c3f0", null ],
    [ "plpsty", "plplotc_8py.html#adef0119c1349ef0917e6b77b56e44321", null ],
    [ "plptex", "plplotc_8py.html#a9fbfda573eb43ca857cdebc599eb0f9c", null ],
    [ "plptex3", "plplotc_8py.html#af5a9c1293df51793b44bd123fedd6be7", null ],
    [ "plrandd", "plplotc_8py.html#a33e52b124892185b83ac257003b9fde4", null ],
    [ "plreplot", "plplotc_8py.html#aaaabe97cd184cc884bcd59f4f1623aa7", null ],
    [ "plResetOpts", "plplotc_8py.html#aee5e09fb23baebcdc6d2f6237bfd6c84", null ],
    [ "plrgbhls", "plplotc_8py.html#acffcfff0cecc9dff746e315652e6539f", null ],
    [ "plschr", "plplotc_8py.html#aa12d53bc25a441d8f1abfdfa41c35dca", null ],
    [ "plscmap0", "plplotc_8py.html#a04090e0e39545b322992322037c1298b", null ],
    [ "plscmap0a", "plplotc_8py.html#a83c667534ac8fccd7e8c3137bc820978", null ],
    [ "plscmap0n", "plplotc_8py.html#a4779a0447b2a270ae5f7304a9325e61a", null ],
    [ "plscmap1", "plplotc_8py.html#aa42636ec0997fe9f2f7801d27ce4a5e0", null ],
    [ "plscmap1_range", "plplotc_8py.html#a091510f7266551167a3181ec484ee209", null ],
    [ "plscmap1a", "plplotc_8py.html#a81c882843c0b69a5787375cb0abfc0d4", null ],
    [ "plscmap1l", "plplotc_8py.html#adfb9c476de303ee014772f6ed7b82a25", null ],
    [ "plscmap1la", "plplotc_8py.html#ac297144db1a467e2821e29bbb5a9eeb3", null ],
    [ "plscmap1n", "plplotc_8py.html#a5e794ebb181b42afadc430ae1b21a6a2", null ],
    [ "plscol0", "plplotc_8py.html#a15c4de8a201050397ff4bd8b71271f83", null ],
    [ "plscol0a", "plplotc_8py.html#a42873e910a92e22ddc40ad33cb60dcec", null ],
    [ "plscolbg", "plplotc_8py.html#ac8a73afee7a4d44db18770493e6deebb", null ],
    [ "plscolbga", "plplotc_8py.html#a864d7c6984219db578ce001a05ebeeaf", null ],
    [ "plscolor", "plplotc_8py.html#a024bb3fc79b423e4157bfff0bd14a3b3", null ],
    [ "plscompression", "plplotc_8py.html#a5c914df2fdd38084952e0820dda0ae0a", null ],
    [ "plsdev", "plplotc_8py.html#a005e373d6b6e1eccf18123558b17f263", null ],
    [ "plsdidev", "plplotc_8py.html#aab973937579c09eb7ce87275fb067020", null ],
    [ "plsdimap", "plplotc_8py.html#a137b05b16f0f9d7e709b7af5b19e5cdc", null ],
    [ "plsdiori", "plplotc_8py.html#aa5777357d591d338104382e5f5500c7a", null ],
    [ "plsdiplt", "plplotc_8py.html#a77dc81db12f1e14f76c1f6fab2f4b1b9", null ],
    [ "plsdiplz", "plplotc_8py.html#ab3d300f76f8b2310e010abd6982e474e", null ],
    [ "plseed", "plplotc_8py.html#adf1c177cede2ebcd20016f71df135dea", null ],
    [ "plsesc", "plplotc_8py.html#acf5e763909b574f20952564108795d73", null ],
    [ "plsetopt", "plplotc_8py.html#af6f215d2eabebcab0523bc91711f3c6c", null ],
    [ "plSetUsage", "plplotc_8py.html#a51c7faeed798cb97e5ed1cb843f6a612", null ],
    [ "plsfam", "plplotc_8py.html#a9d9896ebeca3f9f7fb89a564519e64e4", null ],
    [ "plsfci", "plplotc_8py.html#acceea1ed146ad33cd4f9268a9ca80484", null ],
    [ "plsfnam", "plplotc_8py.html#aeacd23b2bab2429ffeb64b5caf658bf5", null ],
    [ "plsfont", "plplotc_8py.html#a6a5f5c65ac7d4b700f60bc22dfa52935", null ],
    [ "plshade", "plplotc_8py.html#a1d360121542330acfdf5ce1a789b2bd2", null ],
    [ "plshades", "plplotc_8py.html#aac3d86e75bf1e03ae89401b7551d44f8", null ],
    [ "plslabelfunc", "plplotc_8py.html#af2ff7d85c547ae231a00183de0b42e67", null ],
    [ "plsmaj", "plplotc_8py.html#ae81dbd5eeac5b1f5522e8fce55921c75", null ],
    [ "plsmem", "plplotc_8py.html#a049600017f6a36db928c74b68d038199", null ],
    [ "plsmema", "plplotc_8py.html#af90e5e29b1c74cc5371a558463c2b188", null ],
    [ "plsmin", "plplotc_8py.html#aed54fc20583ae31a55ebfbd0af932392", null ],
    [ "plsori", "plplotc_8py.html#a8e5ebf29d01c7cea28b4844fbef42869", null ],
    [ "plspage", "plplotc_8py.html#abf06c8571e34d22ba3433f0c21f4ca6c", null ],
    [ "plspal0", "plplotc_8py.html#a56de0ed9635d3f7261e3011c469ada13", null ],
    [ "plspal1", "plplotc_8py.html#aca736d2105997edb3e669decc3f8b776", null ],
    [ "plspause", "plplotc_8py.html#af3677e860518bd35f44815fd29edaa39", null ],
    [ "plsstrm", "plplotc_8py.html#a834eecfcb37095fccfafdec495d61917", null ],
    [ "plssub", "plplotc_8py.html#ae28d0357b3d592f6c4d1b8a5dd563954", null ],
    [ "plssym", "plplotc_8py.html#a5b0cf0b98e7aef17de1c9c9ad26ddbc0", null ],
    [ "plstar", "plplotc_8py.html#a8b6f2afe5dc8fff9923109e1fbf7fd9e", null ],
    [ "plstart", "plplotc_8py.html#a8656eb107be17c4043bd8d64bde05eb2", null ],
    [ "plstransform", "plplotc_8py.html#a465571f84931e678b3a80abd786f37cd", null ],
    [ "plstring", "plplotc_8py.html#a0b608645be8c25906d138698f3e6db78", null ],
    [ "plstring3", "plplotc_8py.html#ab10a0963246680b3b30927af6dcfb8b3", null ],
    [ "plstripa", "plplotc_8py.html#ae6e3f5d27f5907d1c56d9fb76a6a152d", null ],
    [ "plstripc", "plplotc_8py.html#ad6f3387013c2275841d817b8aa2ce931", null ],
    [ "plstripd", "plplotc_8py.html#aeb80cae03238e69d16ce05a42a49de5d", null ],
    [ "plstyl", "plplotc_8py.html#a675fa8ea19837d6d34233c05cac77af5", null ],
    [ "plsurf3d", "plplotc_8py.html#a068cca94c597f07b6a246b1086002878", null ],
    [ "plsurf3dl", "plplotc_8py.html#a244058200141d1842b2716297adf8d99", null ],
    [ "plsvect", "plplotc_8py.html#a909a0b228b7c71f6f5d200d4a9cf40e9", null ],
    [ "plsvpa", "plplotc_8py.html#a591e099b801859f45f5d14f21a81b0cd", null ],
    [ "plsxax", "plplotc_8py.html#a332888c8dc82dd2b4d8fb7aff7b421d1", null ],
    [ "plsxwin", "plplotc_8py.html#aad1a30f64985bfe257c8fc770ab635ad", null ],
    [ "plsyax", "plplotc_8py.html#a9f7092df9b96a7963f433f340a08f61e", null ],
    [ "plsym", "plplotc_8py.html#afae4ce69ca81726817a9da61e9c0832d", null ],
    [ "plszax", "plplotc_8py.html#ad6a1b88a422e11b3a873474c756ad759", null ],
    [ "pltext", "plplotc_8py.html#a89e9419ec09edc015e206fc445135274", null ],
    [ "pltimefmt", "plplotc_8py.html#aac9823efa203d4a3e664acef1dd47f63", null ],
    [ "pltr0", "plplotc_8py.html#a043699bc96583efa8ac4c19be3a2ea24", null ],
    [ "pltr1", "plplotc_8py.html#aa2dfbd735e255226585612a38bf881d0", null ],
    [ "pltr2", "plplotc_8py.html#a3801a0c8e8ac89c3044741345314856d", null ],
    [ "plvasp", "plplotc_8py.html#af1eca7c146255d91b258377db7b0c483", null ],
    [ "plvect", "plplotc_8py.html#ae461b3acec2e759d061e639db2f9a6ed", null ],
    [ "plvpas", "plplotc_8py.html#a6d1d96d530934efe80b2cd890fbb0875", null ],
    [ "plvpor", "plplotc_8py.html#a3284eda296c7de419e8af294bdb850fe", null ],
    [ "plvsta", "plplotc_8py.html#adc9aa799a9e10d770ba288515f9305d7", null ],
    [ "plw3d", "plplotc_8py.html#a39d6e87adcb97c82873bf1320effcbff", null ],
    [ "plwidth", "plplotc_8py.html#a805fbe4abb9f75dec4f66b21a1d649fb", null ],
    [ "plwind", "plplotc_8py.html#a520a9b1a18b67fa1502864ccb378d5b2", null ],
    [ "plxormod", "plplotc_8py.html#ad99e358b1afacc29d967d0582774b0e2", null ],
    [ "swig_import_helper", "plplotc_8py.html#a6ad5993d91798524f0d1425d136ff51b", null ],
    [ "_newclass", "plplotc_8py.html#aa3f0769fc515941a73a96a2993a88e07", null ],
    [ "_plplotc", "plplotc_8py.html#ac3c13b77c76baac12d69958f88eca623", null ],
    [ "_swig_property", "plplotc_8py.html#a2243add39f4fae0aee223daf4512025b", null ],
    [ "BASE_CONT", "plplotc_8py.html#a8ad0cfa320c20249a5672441c5d41833", null ],
    [ "DRAW_LINEX", "plplotc_8py.html#a1468d03369594fe90e8eb5cc464a859b", null ],
    [ "DRAW_LINEXY", "plplotc_8py.html#ac51a99e6a9f091db6f2996d97f675fd6", null ],
    [ "DRAW_LINEY", "plplotc_8py.html#ae85623e8a7f98f87cf65876928d75951", null ],
    [ "DRAW_SIDES", "plplotc_8py.html#a666c56f6d51ce51bd51c15bde0834f75", null ],
    [ "FACETED", "plplotc_8py.html#a06cb014434e1693c91aafa65d2996c52", null ],
    [ "GRID_CSA", "plplotc_8py.html#a637c93aafb8a043eafe6e45e4c8fe7fe", null ],
    [ "GRID_DTLI", "plplotc_8py.html#a9c46b3ae31f7775cc68888dfe0dd5009", null ],
    [ "GRID_NNAIDW", "plplotc_8py.html#a41083538b2b79e26bb68ceb7f1bd7220", null ],
    [ "GRID_NNI", "plplotc_8py.html#a3017ccbfedf84973d1eb6c1def54bdc1", null ],
    [ "GRID_NNIDW", "plplotc_8py.html#a9dadd7e9c8534b465792964bd952766c", null ],
    [ "GRID_NNLI", "plplotc_8py.html#aed82e9f2bf7583a3528d1eeb494423af", null ],
    [ "MAG_COLOR", "plplotc_8py.html#a00cc4c7170501708af758b576e756ebd", null ],
    [ "MESH", "plplotc_8py.html#a802cc0c25dc3ff6d58524decb1a5b9ce", null ],
    [ "ONEW2B", "plplotc_8py.html#a24af40303ce79b0ad7d3734512ca0801", null ],
    [ "ONEW2D", "plplotc_8py.html#ae98a5cc86ba0792db304008fda820c99", null ],
    [ "PL_BIN_CENTRED", "plplotc_8py.html#a344bc3e3683d146d84938050a523b428", null ],
    [ "PL_BIN_DEFAULT", "plplotc_8py.html#a42cfddc5110553983498c4ca88e4c37b", null ],
    [ "PL_BIN_NOEMPTY", "plplotc_8py.html#ada2b3d0d0d635a3a204008e7e1601bb9", null ],
    [ "PL_BIN_NOEXPAND", "plplotc_8py.html#a45b532276b964995dd6fc5409c84bad9", null ],
    [ "PL_COLORBAR_BACKGROUND", "plplotc_8py.html#af95a7d5b0978b75e6d22742693ef378d", null ],
    [ "PL_COLORBAR_BOUNDING_BOX", "plplotc_8py.html#a911b70c3cb2e34e5177f3ef32a995462", null ],
    [ "PL_COLORBAR_CAP_HIGH", "plplotc_8py.html#a2cab6556f35bc5a4898c23a29b183ae6", null ],
    [ "PL_COLORBAR_CAP_LOW", "plplotc_8py.html#a79edd218d6c47e279ed095bcc59c8f47", null ],
    [ "PL_COLORBAR_CAP_NONE", "plplotc_8py.html#ac930e9b816fcb74ea9c0767f32f3b05f", null ],
    [ "PL_COLORBAR_GRADIENT", "plplotc_8py.html#acf97a545a8de2e5e86353b2dc8ba7ac1", null ],
    [ "PL_COLORBAR_IMAGE", "plplotc_8py.html#a3f30322ca60a874f4fa5dde9eee730ea", null ],
    [ "PL_COLORBAR_LABEL_BOTTOM", "plplotc_8py.html#ad9e518731ed5c7d83b1f23f54ff65e35", null ],
    [ "PL_COLORBAR_LABEL_LEFT", "plplotc_8py.html#a3e4cf1bda8ba1c0505c9562b6c82750c", null ],
    [ "PL_COLORBAR_LABEL_RIGHT", "plplotc_8py.html#adc86862732c28d9f913aaccfdf3ada85", null ],
    [ "PL_COLORBAR_LABEL_TOP", "plplotc_8py.html#a34f25c7749f9f2e7e4b57751f48a7a04", null ],
    [ "PL_COLORBAR_ORIENT_BOTTOM", "plplotc_8py.html#ae9209f36a0d585af6359b592de312c17", null ],
    [ "PL_COLORBAR_ORIENT_LEFT", "plplotc_8py.html#ab71b2b1310d91961d4474debc45f6795", null ],
    [ "PL_COLORBAR_ORIENT_RIGHT", "plplotc_8py.html#af433eeb18a32c898a75b2395d7469a56", null ],
    [ "PL_COLORBAR_ORIENT_TOP", "plplotc_8py.html#a52066881c06bed4cbeb01c5da3d74ccc", null ],
    [ "PL_COLORBAR_SHADE", "plplotc_8py.html#a4ff5e3c86ff6f9d3e2e223c490fe8327", null ],
    [ "PL_COLORBAR_SHADE_LABEL", "plplotc_8py.html#ad5adcf8af18fbe8ade0593944543b260", null ],
    [ "PL_DRAWMODE_DEFAULT", "plplotc_8py.html#a4d91914c408b6a2404caad751109bdfa", null ],
    [ "PL_DRAWMODE_REPLACE", "plplotc_8py.html#a63a3b10a62df8f5eff9deb07d38bbef6", null ],
    [ "PL_DRAWMODE_UNKNOWN", "plplotc_8py.html#a28125d34c086e0128f19a6c8a7ed0dac", null ],
    [ "PL_DRAWMODE_XOR", "plplotc_8py.html#ac4cd01bfca501d2b0fab88269b97cd4d", null ],
    [ "PL_FCI_BOLD", "plplotc_8py.html#a2c7bb357576ac33c8276882983ecffac", null ],
    [ "PL_FCI_FAMILY", "plplotc_8py.html#aaf207b29fc82b13ce1ce2f128ca5f37b", null ],
    [ "PL_FCI_HEXDIGIT_MASK", "plplotc_8py.html#a572183dfc5e2aacd72c5d46ada49772f", null ],
    [ "PL_FCI_HEXPOWER_IMPOSSIBLE", "plplotc_8py.html#a71e15c798240dd024f8ae5389501e87f", null ],
    [ "PL_FCI_HEXPOWER_MASK", "plplotc_8py.html#aeba6a59a54184036d545cfaee0835afc", null ],
    [ "PL_FCI_IMPOSSIBLE", "plplotc_8py.html#a59db6556c1037fa49ce96a07e48459d7", null ],
    [ "PL_FCI_ITALIC", "plplotc_8py.html#a9f951c9bf12df563e8325e76ca9aaca0", null ],
    [ "PL_FCI_MARK", "plplotc_8py.html#a6e7400cf778bda55234053f0a5bb833e", null ],
    [ "PL_FCI_MEDIUM", "plplotc_8py.html#ac05bf1cddf518c5c5afb50f415915b90", null ],
    [ "PL_FCI_MONO", "plplotc_8py.html#a63b05e5c0adf5f35662989ae1fae3f20", null ],
    [ "PL_FCI_OBLIQUE", "plplotc_8py.html#a0421edff31f5a68120efcf9c738c06b6", null ],
    [ "PL_FCI_SANS", "plplotc_8py.html#a964ab0d5d6bb4c2a7a5b62bf56a13ad8", null ],
    [ "PL_FCI_SCRIPT", "plplotc_8py.html#a16597c0a15eecef215370eed9d425f57", null ],
    [ "PL_FCI_SERIF", "plplotc_8py.html#ad964edc69413999f4cc508a3ed91bc38", null ],
    [ "PL_FCI_STYLE", "plplotc_8py.html#a48d8e4607986d922bffd7f2440540bab", null ],
    [ "PL_FCI_SYMBOL", "plplotc_8py.html#a7deb908680041aa6345b04e72e815092", null ],
    [ "PL_FCI_UPRIGHT", "plplotc_8py.html#a91b81d08c1ddc31132b0159b625e1127", null ],
    [ "PL_FCI_WEIGHT", "plplotc_8py.html#a3a3f9833554fe851af77f023f8c7be7b", null ],
    [ "PL_HIST_DEFAULT", "plplotc_8py.html#a845525a70d0881cf4dee35d7a2dfbe0d", null ],
    [ "PL_HIST_IGNORE_OUTLIERS", "plplotc_8py.html#a7cc56d537c892f81cffef2f8d4ee7958", null ],
    [ "PL_HIST_NOEMPTY", "plplotc_8py.html#acbcfe2e7e708cb029f1c97cc3a85926b", null ],
    [ "PL_HIST_NOEXPAND", "plplotc_8py.html#aabf92588e101123e2f89c4dbd8e36e90", null ],
    [ "PL_HIST_NOSCALING", "plplotc_8py.html#a86292e97bfbef7878d6b68c564fe9381", null ],
    [ "PL_LEGEND_BACKGROUND", "plplotc_8py.html#abc4a2e8a493084e9577ef11f4d62b208", null ],
    [ "PL_LEGEND_BOUNDING_BOX", "plplotc_8py.html#af601e258b515c6b07eab9c046f4d197e", null ],
    [ "PL_LEGEND_COLOR_BOX", "plplotc_8py.html#a4b4963c66abfe6a3524bf1ce73a579a5", null ],
    [ "PL_LEGEND_LINE", "plplotc_8py.html#a6a5b7d6a12dcc9730aa2d09d04ca2f52", null ],
    [ "PL_LEGEND_NONE", "plplotc_8py.html#aead30eae9759fe6e920f33f312a79aae", null ],
    [ "PL_LEGEND_ROW_MAJOR", "plplotc_8py.html#ae7dffb9a57c39e4ac16aa729c2917221", null ],
    [ "PL_LEGEND_SYMBOL", "plplotc_8py.html#ad845ed17a7e9050c76c224b3562bbd57", null ],
    [ "PL_LEGEND_TEXT_LEFT", "plplotc_8py.html#a5bc571eac419099c60599e939ad4d714", null ],
    [ "PL_MAXKEY", "plplotc_8py.html#aee4112232cec089f90d4f7d92b4f0d86", null ],
    [ "PL_MAXWINDOWS", "plplotc_8py.html#a779a1499d3588bc9c76e568ba2df3c32", null ],
    [ "PL_NOTSET", "plplotc_8py.html#aed76bc0c511df9cd6716ca28cbffe1a9", null ],
    [ "PL_OPT_ARG", "plplotc_8py.html#aaf00cc20965dced0e4123bed06e74d1e", null ],
    [ "PL_OPT_BOOL", "plplotc_8py.html#a5e8f3261578b8694402e1f36d8ca1c7e", null ],
    [ "PL_OPT_DISABLED", "plplotc_8py.html#abd6c285cf0ebb6c14039f0cafd8e401b", null ],
    [ "PL_OPT_ENABLED", "plplotc_8py.html#ac02ececdcc757965e88a276bd64df715", null ],
    [ "PL_OPT_FLOAT", "plplotc_8py.html#a96772303c09747ebd4a5b97113497771", null ],
    [ "PL_OPT_FUNC", "plplotc_8py.html#a8243ce1acc41ce3a9c6a0a70d3ad6525", null ],
    [ "PL_OPT_INT", "plplotc_8py.html#ac5d4da34148933be221174c149277220", null ],
    [ "PL_OPT_INVISIBLE", "plplotc_8py.html#a44a1e35b8c895002867f93fc163fee29", null ],
    [ "PL_OPT_NODELETE", "plplotc_8py.html#a1496de58bd6272dee9f8373f551b377c", null ],
    [ "PL_OPT_STRING", "plplotc_8py.html#afc6c6d9d92c1b411d0d578599666b51e", null ],
    [ "PL_PARSE_FULL", "plplotc_8py.html#aa88dd5322e244335e99a41d9ef881698", null ],
    [ "PL_PARSE_NODASH", "plplotc_8py.html#aff2af8dffef5de6dbcdecc701f03d5af", null ],
    [ "PL_PARSE_NODELETE", "plplotc_8py.html#ac066b1e47e6b44cd79eac4ea3be39ed3", null ],
    [ "PL_PARSE_NOPROGRAM", "plplotc_8py.html#a25c0d78bfe8bc79a147650563750465a", null ],
    [ "PL_PARSE_OVERRIDE", "plplotc_8py.html#a496639e6132709a0dd24849413a4deef", null ],
    [ "PL_PARSE_PARTIAL", "plplotc_8py.html#a0d93f43441998f2de93036815020f71a", null ],
    [ "PL_PARSE_QUIET", "plplotc_8py.html#a4467ee661a8937b1f879a751eeeeadc3", null ],
    [ "PL_PARSE_SHOWALL", "plplotc_8py.html#aa8690112cb60dbe018f43a2a3c29fdbc", null ],
    [ "PL_PARSE_SKIP", "plplotc_8py.html#a93ea921c3ed513199ab81a93ac6a460d", null ],
    [ "PL_POSITION_BOTTOM", "plplotc_8py.html#a8a72b5e17704c55222b3c67125e321bd", null ],
    [ "PL_POSITION_INSIDE", "plplotc_8py.html#a9fed591aa8a475128add157fff0e5fde", null ],
    [ "PL_POSITION_LEFT", "plplotc_8py.html#a0d3481596075477e2d0ef8a20e608d6b", null ],
    [ "PL_POSITION_OUTSIDE", "plplotc_8py.html#ad963a64f3db3c6784e98f2b0d9a69cd5", null ],
    [ "PL_POSITION_RIGHT", "plplotc_8py.html#a0b31589c970ace749e230d4e4f8b2f8e", null ],
    [ "PL_POSITION_SUBPAGE", "plplotc_8py.html#a4fb867b72c453a2a11c8ba032f13489f", null ],
    [ "PL_POSITION_TOP", "plplotc_8py.html#a0abd0e9822ad69dbfb0aa3dff1792108", null ],
    [ "PL_POSITION_VIEWPORT", "plplotc_8py.html#a4d5ed12522251a89cef03d18fd5bfcda", null ],
    [ "PL_X_AXIS", "plplotc_8py.html#a8aa8ffa99953ead9bfb1f6325278ffac", null ],
    [ "PL_Y_AXIS", "plplotc_8py.html#aec4a4c625c8cbdface2c1502a4d54417", null ],
    [ "PL_Z_AXIS", "plplotc_8py.html#ab38e608332e8694686898c0e7384e1b3", null ],
    [ "plClearOpts", "plplotc_8py.html#a3b5a47229240d9a24ca61397dd0569c2", null ],
    [ "PLESC_ALLOC_NCOL", "plplotc_8py.html#af5019f03e5604c1591d4d3ecef40417a", null ],
    [ "PLESC_APPEND_BUFFER", "plplotc_8py.html#a3c1b5742671c7991e48b411268807b40", null ],
    [ "PLESC_ARC", "plplotc_8py.html#a88c9dd3a5c5c4ff2900db7a7ee815d69", null ],
    [ "PLESC_BEGIN_TEXT", "plplotc_8py.html#aafa90b4565f0f69e93351cba71598990", null ],
    [ "PLESC_CLEAR", "plplotc_8py.html#a876cf74842ce228ee028a8106c825cce", null ],
    [ "PLESC_CONTROL_CHAR", "plplotc_8py.html#a98d1b2377be5102740d2b3b76af18f7d", null ],
    [ "PLESC_DASH", "plplotc_8py.html#a1df41bbf8effa531f0d1fdfc2325e8e7", null ],
    [ "PLESC_DEV2PLCOL", "plplotc_8py.html#ab34b545559e6fc12ddb7d9505e32d22f", null ],
    [ "PLESC_DEVINIT", "plplotc_8py.html#aa215fe460d2699f9c0ae02fa51b13f43", null ],
    [ "PLESC_DI", "plplotc_8py.html#a3b826bbf936c421419d798faa46dc584", null ],
    [ "PLESC_DOUBLEBUFFERING", "plplotc_8py.html#aab012aabef62dba42e2a0d58ed0b6f0d", null ],
    [ "PLESC_DOUBLEBUFFERING_DISABLE", "plplotc_8py.html#ac62d2827edd6f5b51a16b3ccd95e9c0c", null ],
    [ "PLESC_DOUBLEBUFFERING_ENABLE", "plplotc_8py.html#a1e75cfe296046477e9ac7c4d67c28c26", null ],
    [ "PLESC_DOUBLEBUFFERING_QUERY", "plplotc_8py.html#ae6b5e6b02baa32afdaac6c1e8d2f236e", null ],
    [ "PLESC_EH", "plplotc_8py.html#a195e11c9ce77a2bbab16767d008b111f", null ],
    [ "PLESC_END_RASTERIZE", "plplotc_8py.html#ab910687e7e7afadd653db3f4d48b148e", null ],
    [ "PLESC_END_TEXT", "plplotc_8py.html#a6029ac27c7ef2a0e783ca0cb5635e477", null ],
    [ "PLESC_EXPOSE", "plplotc_8py.html#ae38e7b767f85ab19c019a2c739cc7761", null ],
    [ "PLESC_FILL", "plplotc_8py.html#a0161658227f3be0036ce2be29b831977", null ],
    [ "PLESC_FIXASPECT", "plplotc_8py.html#ab30919de5123e4ff1faeb71651cab801", null ],
    [ "PLESC_FLUSH", "plplotc_8py.html#aae31cc0d750e429823e7722a4c629edc", null ],
    [ "PLESC_FLUSH_REMAINING_BUFFER", "plplotc_8py.html#aafb7d40ef560973c189bd1af7ea51cad", null ],
    [ "PLESC_GETBACKEND", "plplotc_8py.html#afe5bfb8be365234aef2097a735c35744", null ],
    [ "PLESC_GETC", "plplotc_8py.html#a19d4d2d2836911342deb0281d2e24059", null ],
    [ "PLESC_GRADIENT", "plplotc_8py.html#aacf6b5fe12c4d85313aa861dfa3b84e7", null ],
    [ "PLESC_GRAPH", "plplotc_8py.html#a23db208de6ec19317b2f5f7e50304537", null ],
    [ "PLESC_HAS_TEXT", "plplotc_8py.html#af5c0c3836b5e1581d3be64ef852cb13f", null ],
    [ "PLESC_IMAGE", "plplotc_8py.html#a7b8b082fd76f82e745e7c0495a50879e", null ],
    [ "PLESC_IMAGEOPS", "plplotc_8py.html#aeda20276a961b9f1ce5534c3ce37245e", null ],
    [ "PLESC_IMPORT_BUFFER", "plplotc_8py.html#aca0fe6617fc7fa33eef6df4f2a8eb530", null ],
    [ "PLESC_MODEGET", "plplotc_8py.html#a0319c9e155afcbb122d170f627848c1f", null ],
    [ "PLESC_MODESET", "plplotc_8py.html#a8b9fd0ad5393f5301a06f36b878f4b19", null ],
    [ "PLESC_PL2DEVCOL", "plplotc_8py.html#ab9198fb986a29a87c3eabd6e36e5ddab", null ],
    [ "PLESC_REDRAW", "plplotc_8py.html#a193d81301fd059cd7fdcf8a883a46d3a", null ],
    [ "PLESC_RESIZE", "plplotc_8py.html#a57016284408a7b4832c0509e9d37b06e", null ],
    [ "PLESC_SET_COMPRESSION", "plplotc_8py.html#ab4ed01c814c5efbf1cf072f18592475a", null ],
    [ "PLESC_SET_LPB", "plplotc_8py.html#a7e5cb39b69896c1a5d68304ad0a02943", null ],
    [ "PLESC_SET_RGB", "plplotc_8py.html#ada7b8a924fb783340dacd8e8a1d33e87", null ],
    [ "PLESC_SETBGFG", "plplotc_8py.html#a86d0b98cb046098478970b53738c0916", null ],
    [ "PLESC_START_RASTERIZE", "plplotc_8py.html#af9742dda23e8d3f662e1cb2a3a525148", null ],
    [ "PLESC_SWIN", "plplotc_8py.html#a15d0a541754c8cf11fa3b80c9a8c1f6f", null ],
    [ "PLESC_TEXT", "plplotc_8py.html#ab412042d6d3501a95aeb452b1bc34ffb", null ],
    [ "PLESC_TEXT_CHAR", "plplotc_8py.html#a78f3b4c904b70f3c49f9ccb9bf79083b", null ],
    [ "PLESC_XORMOD", "plplotc_8py.html#a32d1e35e35329b80334d9c61dc442f52", null ],
    [ "plGetCursor", "plplotc_8py.html#a113311917620d161413e7706a83975da", null ],
    [ "PLGraphicsIn_swigregister", "plplotc_8py.html#a2ed140e1dae13d8870800c18255c50f5", null ],
    [ "plMinMax2dGrid", "plplotc_8py.html#a02d5cc5e9830406ed04d933dc91b5f34", null ],
    [ "plOptUsage", "plplotc_8py.html#a91a52af2917540a0f9fa00c3c55c2dd2", null ],
    [ "plResetOpts", "plplotc_8py.html#af38c58a760449cb53d7b41b76d19b27b", null ],
    [ "plSetUsage", "plplotc_8py.html#a21768491ad01b676ba51c3fe07729727", null ],
    [ "PLSWIN_DEVICE", "plplotc_8py.html#a9546c5be25c4dee3cedf4d3531e0a271", null ],
    [ "PLSWIN_WORLD", "plplotc_8py.html#a068d68799b04f081e6647a74cc239049", null ],
    [ "plsxwin", "plplotc_8py.html#a334c3242c3767b8820e67016c523434f", null ],
    [ "PLTEXT_BACKCHAR", "plplotc_8py.html#a3d7a89e051b17190397dfceee0498fa6", null ],
    [ "PLTEXT_FONTCHANGE", "plplotc_8py.html#a898327e28e20a75486b73eb0bd38fafc", null ],
    [ "PLTEXT_OVERLINE", "plplotc_8py.html#a1f8604c47436bdaa3e323c633c669874", null ],
    [ "PLTEXT_SUBSCRIPT", "plplotc_8py.html#ae2fa706d7ce77d27b12df4d1dd6ddf39", null ],
    [ "PLTEXT_SUPERSCRIPT", "plplotc_8py.html#a873a0fb7dee097cd6a1a9586327863c7", null ],
    [ "PLTEXT_UNDERLINE", "plplotc_8py.html#a6a448b26bc2a80db2cb5736710d27cf4", null ],
    [ "pltr0", "plplotc_8py.html#a1a3d30415da615635d94e4b2c3d96204", null ],
    [ "pltr1", "plplotc_8py.html#a5ab0ac0ec378324110aa4e00e0f5aab4", null ],
    [ "pltr2", "plplotc_8py.html#ade02f9b8fdd455998a19d329c375efb5", null ],
    [ "SURF_CONT", "plplotc_8py.html#a2a06158f530effb271f9b815c6eb2e81", null ],
    [ "TOP_CONT", "plplotc_8py.html#a1c498b000475105a916b46c164580ee7", null ],
    [ "ZEROW2B", "plplotc_8py.html#a7afe9d095b3bcc4d93d1ffbb68284366", null ],
    [ "ZEROW2D", "plplotc_8py.html#abd9ad3f40340e4001cfddd19f82d471e", null ]
];